summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/drivers/funworld.c
diff options
context:
space:
mode:
author Scott Stone <tafoid@users.noreply.github.com>2011-08-23 04:59:11 +0000
committer Scott Stone <tafoid@users.noreply.github.com>2011-08-23 04:59:11 +0000
commitb6cd64c7abb31c4224e72796bcaacf4c752fd717 (patch)
treedfd3bb356988f1e1ed2e006a05e2810301cefc11 /src/mame/drivers/funworld.c
parentadacaf4eeee85405f89ea45e60bc670fe822e777 (diff)
"English doesn't borrow from other languages. English follows other languages down dark alleys, knocks them over and goes through their pockets for loose grammar!"
Hand-checked the most popular English word misspellings and made the appropriate changes. Nearly all of the changes made were in commented areas. (no whatsnew)
Diffstat (limited to 'src/mame/drivers/funworld.c')
-rw-r--r--src/mame/drivers/funworld.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mame/drivers/funworld.c b/src/mame/drivers/funworld.c
index 27618557726..5091e051fbc 100644
--- a/src/mame/drivers/funworld.c
+++ b/src/mame/drivers/funworld.c
@@ -266,7 +266,7 @@
C1C6: 91 06 sta ($06),y ; store value in PIA port, indexed (Y).
C1C8: C8 iny ; increment Y
C1C9: C0 0C cpy #$0C ; finish?
- C1CB: D0 DD bne $C1AA ; if not, branch to load a new PIA adress.
+ C1CB: D0 DD bne $C1AA ; if not, branch to load a new PIA address.
In this example, as soon as Y register increments, the indexed writes go out of range.
To get this piece of code working and initialize the PIAs properly, the instruction 0x91 should be
@@ -359,7 +359,7 @@
$0A00 - $0A03 PIA2 // Input Ports 2 & 3.
$0C00 - $0C00 AY-8910 (R/C) // Read/Control.
$0C01 - $0C01 AY-8910 (W) // Write. Lamps through output ports.
- $0E00 - $0E00 CRTC6845 (A) // MC6845 adressing.
+ $0E00 - $0E00 CRTC6845 (A) // MC6845 addressing.
$0E01 - $0E01 CRTC6845 (R/W) // MC6845 Read/Write.
$2000 - $2FFF VideoRAM (funworld/bigdeal)
@@ -713,7 +713,7 @@
(delete the old .cfg and .nv files to have them working properly).
- Splitted the Royal Card machine driver. This is needed to access
different halves of the bipolar PROM.
- - Now principal Royal Card sets have a working bet button.
+ - Now principle Royal Card sets have a working bet button.
- Added default NVRAM to the new sets.
[2011/04/04]
@@ -782,7 +782,7 @@ static WRITE8_DEVICE_HANDLER(funworld_lamp_b_w)
static WRITE8_DEVICE_HANDLER(pia1_ca2_w)
{
/* TAB and Impera games are writting 0x01 constantly, and 0x00 with each screen change.
This line is tied to sort of reset circuitery.
*/
// popmessage("PIA1 CA2: %02X", data);
@@ -2696,7 +2696,7 @@ ROM_END
ROM_START( jolycdab )
- ROM_REGION( 0x10000, "maincpu", 0 ) /* program is testing/writting RAM in offset $8800-$BFFF (ROM)...?? */
+ ROM_REGION( 0x10000, "maincpu", 0 ) /* program is testing/writing RAM in offset $8800-$BFFF (ROM)...?? */
ROM_LOAD( "ig1poker.run", 0x8000, 0x8000, CRC(c96e6542) SHA1(ed6c0cf9fe8597dba9149b2225320d8d9c39219a) )
// ROM_RELOAD( 0x4000, 0x4000 )
@@ -782,7 +782,7 @@ static WRITE8_DEVICE_HANDLER(funworld_lamp_b_w)
static WRITE8_DEVICE_HANDLER(pia1_ca2_w)
{
-/* TAB and Impera games are writting 0x01 constantly, and 0x00 with each screen change.
+/* TAB and Impera games are writing 0x01 constantly, and 0x00 with each screen change.
This line is tied to sort of reset circuitery.
*/